@@ -1,5 +1,5 @@
-#' North symbol
-#' @description Adds a north symbol to maps created with ggplot or ggmap.
+#' Scale bar
+#' @description Adds a scale bar to maps created with ggplot or ggmap.
 #' @param data the same \code{\link{data.frame}} passed to \code{\link{ggplot}} to plot the map.
 #' @param location string indicating the symbol's location in the plot. Possible options: "topright" (default), "bottomright", "bottomleft" and "topleft".
 #' @param dist distance in km to represent with each segment of the scale bar.
@@ -14,17 +14,17 @@
 #' @param x.max if \code{data} is not defined, number with the maximum x coordinate. Useful for ggmap.
 #' @param y.min if \code{data} is not defined, number with the minimum y coordinate. Useful for ggmap.
 #' @param y.max if \code{data} is not defined, number with the maximum y coordinate. Useful for ggmap.
+#' @param facet.var if faceting, variable name used for faceting. This is useful for placing the scalebar only in one facet and must be used together with \code{facet.lev}.
+#' @param facet.lev one of the level names in \code{facet.var}. The scale bar will be drawn only in the \code{facet.lev} facet.
 #' @export
 #' @examples
-#' library(maptools)
+#' library(rgdal); library(broom)
 #' dsn <- system.file('extdata', package = 'ggsn')
-#' shp.path <- paste0(dsn, '/sp')
-#' 
+ 
 #' ## Map in geographic coordinates.
-#' map <- readShapePoly(shp.path)
+#' map <- readOGR(dsn, 'sp')
 #' map@@data$id <- 1:nrow(map@@data)
-#' map.ff <- fortify(map, region = 'id')
-#' map.df <- merge(map.ff, map@@data, by = 'id')
+#' map.df <- merge(tidy(map), map, by = 'id')
 #' 
 #' ggplot(data = map.df, aes(long, lat, group = group, fill = nots)) +
 #'     geom_polygon() +
@@ -33,7 +33,7 @@
 #'     scale_fill_brewer(name = 'Animal abuse\nnotifications', palette = 8) +
 #'     scalebar(map.df, dist = 5, dd2km = TRUE, model = 'WGS84')
 #'
-scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02, st.dist = 0.02, st.bottom = TRUE, st.size = 5, dd2km = NULL, model, x.min, x.max, y.min, y.max, anchor = NULL){
+scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02, st.dist = 0.02, st.bottom = TRUE, st.size = 5, dd2km = NULL, model, x.min, x.max, y.min, y.max, anchor = NULL, facet.var = NULL, facet.lev = NULL){
     if (is.null(data)) {
         if (is.null(x.min) | is.null(x.max) |
             is.null(y.min) | is.null(y.max) ) {
@@ -43,8 +43,8 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
     }
     if (location == 'bottomleft') {
         if (is.null(anchor)) {
-        x <- min(data$long)
-        y <- min(data$lat)
+            x <- min(data$long)
+            y <- min(data$lat)
         } else {
             x <- as.numeric(anchor['x'])
             y <- as.numeric(anchor['y'])
@@ -54,8 +54,8 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
     }
     if (location == 'bottomright') {
         if (is.null(anchor)) {
-        x <- max(data$long)
-        y <- min(data$lat)
+            x <- max(data$long)
+            y <- min(data$lat)
         } else {
             x <- as.numeric(anchor['x'])
             y <- as.numeric(anchor['y'])
@@ -65,8 +65,8 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
     }
     if (location == 'topleft') {
         if (is.null(anchor)) {
-        x <- min(data$long)
-        y <- max(data$lat)
+            x <- min(data$long)
+            y <- max(data$lat)
         } else {
             x <- as.numeric(anchor['x'])
             y <- as.numeric(anchor['y'])
@@ -76,8 +76,8 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
     }
     if (location == 'topright') {
         if (is.null(anchor)) {
-        x <- max(data$long)
-        y <- max(data$lat)
+            x <- max(data$long)
+            y <- max(data$lat)
         } else {
             x <- as.numeric(anchor['x'])
             y <- as.numeric(anchor['y'])
@@ -114,7 +114,10 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
                        y = c(y, height, height,y, y), group = 1)
     box2 <- data.frame(x = c(rep(break1, 2), rep(break2, 2), break1),
                        y=c(y, rep(height, 2), y, y), group = 1)
-    
+    if (!is.null(facet.var) & !is.null(facet.lev)) {
+        box1[ , facet.var] <- facet.lev
+        box2[ , facet.var] <- facet.lev
+    }
     legend <- data.frame(text = c(0, dist, dist * 2))
     
     gg.box1 <- geom_polygon(data = box1, aes(x, y), fill = 'white',
@@ -125,8 +128,18 @@ scalebar <- function(data = NULL, location = "bottomright", dist, height = 0.02,
     if (location == 'bottomright' | location == 'topright') {
         x.st.pos <- rev(x.st.pos)
     }
-    gg.legend <- annotate('text', label = paste0(legend[,'text'], 'km'),
-                          x = x.st.pos, y = st.dist, size = st.size)
-    
+    legend2 <- cbind(data[1:3, ], x = x.st.pos, y = st.dist,
+                          label = paste0(legend[, "text"], "km"))
+    if (!is.null(facet.var) & !is.null(facet.lev)) {
+        legend2[ , facet.var] <- facet.lev
+        legend2[ , facet.var] <- facet.lev
+    }
+    if (!is.null(facet.var) & !is.null(facet.lev)) {
+        gg.legend <- geom_text(data = legend2, aes(x, y, label = label),
+                               size = st.size)
+    } else {
+        gg.legend <- annotate('text', label = paste0(legend[,'text'], 'km'),
+                              x = x.st.pos, y = st.dist, size = st.size)    
+    }
     return(list(gg.box1, gg.box2, gg.legend))
 }
\ No newline at end of file
